@@ -1,24 +1,11 @@
-/***********************************************************************
- *
- * Copyright (C) 2011, 2012, 2013, 2014, 2015 Graeme Gott <graeme@gottcode.org>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
- ***********************************************************************/
+/*
+	SPDX-FileCopyrightText: 2011-2015 Graeme Gott <graeme@gottcode.org>
 
-#ifndef ODT_READER_H
-#define ODT_READER_H
+	SPDX-License-Identifier: GPL-3.0-or-later
+*/
+
+#ifndef FOCUSWRITER_ODT_READER_H
+#define FOCUSWRITER_ODT_READER_H
 
 #include "format_reader.h"
 
@@ -31,10 +18,10 @@ class OdtReader : public FormatReader
 	Q_DECLARE_TR_FUNCTIONS(OdtReader)
 
 public:
-	OdtReader();
+	explicit OdtReader();
 
 	enum { Type = 3 };
-	int type() const
+	int type() const override
 	{
 		return Type;
 	}
@@ -42,7 +29,7 @@ public:
 	static bool canRead(QIODevice* device);
 
 private:
-	void readData(QIODevice* device);
+	void readData(QIODevice* device) override;
 	void readDataCompressed(QIODevice* device);
 	void readDataUncompressed(QIODevice* device);
 	void readDocument();
@@ -62,7 +49,8 @@ private:
 	struct Style
 	{
 		Style(const QTextBlockFormat& block_format_ = QTextBlockFormat(), const QTextCharFormat& char_format_ = QTextCharFormat())
-			: block_format(block_format_), char_format(char_format_)
+			: block_format(block_format_)
+			, char_format(char_format_)
 		{
 		}
 
@@ -76,4 +64,4 @@ private:
 	bool m_in_block;
 };
 
-#endif
+#endif // FOCUSWRITER_ODT_READER_H
