@@ -29,25 +29,12 @@
 </context>
 <context>
     <name>DailyProgress</name>
-    <message numerus="yes">
-        <source>%L1% of %Ln minute(s)</source>
-        <translation>
-            <numerusform>%L1% de %Ln minuto</numerusform>
-            <numerusform>%L1% de %Ln minutos</numerusform>
-        </translation>
-    </message>
-    <message numerus="yes">
-        <source>%L1% of %Ln word(s)</source>
-        <translation>
-            <numerusform>%L1% de %Ln palavra</numerusform>
-            <numerusform>%L1% de %Ln palavras</numerusform>
-        </translation>
-    </message>
     <message numerus="yes">
         <source>%Ln word(s)</source>
         <translation>
             <numerusform>%Ln palavra</numerusform>
             <numerusform>%Ln palavras</numerusform>
+            <numerusform>%Ln palavras</numerusform>
         </translation>
     </message>
     <message numerus="yes">
@@ -55,12 +42,29 @@
         <translation>
             <numerusform>%Ln minuto</numerusform>
             <numerusform>%Ln minutos</numerusform>
+            <numerusform>%Ln minutos</numerusform>
         </translation>
     </message>
     <message>
         <source>0%</source>
         <translation>0%</translation>
     </message>
+    <message numerus="yes">
+        <source>%L1% of %Ln minute(s)</source>
+        <translation>
+            <numerusform>%L1% de %Ln minuto</numerusform>
+            <numerusform>%L1% de %Ln minutos</numerusform>
+            <numerusform>%L1% de %Ln minutos</numerusform>
+        </translation>
+    </message>
+    <message numerus="yes">
+        <source>%L1% of %Ln word(s)</source>
+        <translation>
+            <numerusform>%L1% de %Ln palavra</numerusform>
+            <numerusform>%L1% de %Ln palavras</numerusform>
+            <numerusform>%L1% de %Ln palavras</numerusform>
+        </translation>
+    </message>
 </context>
 <context>
     <name>DailyProgressDialog</name>
@@ -85,6 +89,7 @@
         <translation>
             <numerusform>%n dia</numerusform>
             <numerusform>%n dias</numerusform>
+            <numerusform>%n dias</numerusform>
         </translation>
     </message>
     <message>
@@ -266,6 +271,7 @@
         <translation>
             <numerusform>Substituir %n ocorrência?</numerusform>
             <numerusform>Substituir %n ocorrências?</numerusform>
+            <numerusform>Substituir %n ocorrências?</numerusform>
         </translation>
     </message>
     <message>
@@ -334,8 +340,8 @@
         <translation>Abrir Imagem</translation>
     </message>
     <message>
-        <source>Images(%1)</source>
-        <translation>Imagens(%1)</translation>
+        <source>Images</source>
+        <translation>Imagens</translation>
     </message>
 </context>
 <context>
@@ -588,11 +594,11 @@
     </message>
     <message>
         <source>Move Up</source>
-        <translation>Subir</translation>
+        <translation>Para cima</translation>
     </message>
     <message>
         <source>Move Down</source>
-        <translation>Descer</translation>
+        <translation>Para baixo</translation>
     </message>
     <message>
         <source>Add Separator</source>
@@ -677,7 +683,7 @@
     <name>SceneList</name>
     <message>
         <source>Ctrl+Shift+Down</source>
-        <translation>Ctrl+Shift+Seta para Abaixo</translation>
+        <translation>Ctrl+Shift+Seta para Baixo</translation>
     </message>
     <message>
         <source>Move Scenes Up</source>
@@ -685,7 +691,7 @@
     </message>
     <message>
         <source>Ctrl+Shift+Up</source>
-        <translation>Ctrl+Shift+Seta para Acima</translation>
+        <translation>Ctrl+Shift+Seta para Cima</translation>
     </message>
     <message>
         <source>Toggle Scene List</source>
@@ -1579,7 +1585,7 @@
     </message>
     <message>
         <source>Sup&amp;erscript</source>
-        <translation>Sobr%escrito</translation>
+        <translation>Sobr&amp;escrito</translation>
     </message>
     <message>
         <source>Ctrl+^</source>
@@ -1854,4 +1860,11 @@
         <translation>Ctrl+Shift+`</translation>
     </message>
 </context>
+<context>
+    <name>main</name>
+    <message>
+        <source>Files to open in current session.</source>
+        <translation>Ficheiros a abrir na sessão em curso.</translation>
+    </message>
+</context>
 </TS>
