@@ -34,6 +34,7 @@
         <translation>
             <numerusform>%Ln palavra</numerusform>
             <numerusform>%Ln palavras</numerusform>
+            <numerusform>%Ln palavras</numerusform>
         </translation>
     </message>
     <message numerus="yes">
@@ -41,6 +42,7 @@
         <translation>
             <numerusform>%Ln minuto</numerusform>
             <numerusform>%Ln minutos</numerusform>
+            <numerusform>%Ln minutos</numerusform>
         </translation>
     </message>
     <message>
@@ -52,6 +54,7 @@
         <translation>
             <numerusform>%L1% de %Ln minutoo</numerusform>
             <numerusform>%L1% de %Ln minutos</numerusform>
+            <numerusform>%L1% de %Ln minutos</numerusform>
         </translation>
     </message>
     <message numerus="yes">
@@ -59,6 +62,7 @@
         <translation>
             <numerusform>%L1% de %Ln palavra</numerusform>
             <numerusform>%L1% de %Ln palavras</numerusform>
+            <numerusform>%L1% de %Ln palavras</numerusform>
         </translation>
     </message>
 </context>
@@ -85,6 +89,7 @@
         <translation>
             <numerusform>%n dia</numerusform>
             <numerusform>%n dias</numerusform>
+            <numerusform>%n dias</numerusform>
         </translation>
     </message>
     <message>
@@ -266,6 +271,7 @@
         <translation>
             <numerusform>Substituir %n ocorrência?</numerusform>
             <numerusform>Substituir %n ocorrências?</numerusform>
+            <numerusform>Substituir %n ocorrências?</numerusform>
         </translation>
     </message>
     <message>
@@ -652,7 +658,7 @@
     </message>
     <message>
         <source>Always show top bar</source>
-        <translation>MOstrar sempre a barra superior</translation>
+        <translation>Mostrar sempre a barra superior</translation>
     </message>
     <message>
         <source>Always show bottom bar</source>
