@@ -346,8 +346,8 @@
         <translation>Odpri sliko</translation>
     </message>
     <message>
-        <source>Images(%1)</source>
-        <translation>Slike(%1)</translation>
+        <source>Images</source>
+        <translation>Slike</translation>
     </message>
 </context>
 <context>
@@ -1866,4 +1866,11 @@
         <translation>Ctrl+Shift+`</translation>
     </message>
 </context>
+<context>
+    <name>main</name>
+    <message>
+        <source>Files to open in current session.</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 </TS>
